# Kodexa

![Build](https://github.com/kodexa-ai/kodexa/workflows/Python%20Package%20Using%20Anaconda/badge.svg)
[![Slack](https://slack.kodexa.com/badge.svg?version)](https://slack.kodexa.com/)


The Kodexa Content Framework framework is designed to allow you to work with a wide range of unstructured and semi-structured content and enables you to work with the Kodexa Platform (https://platform.kodexa.com).

## Documentation & Examples

Documentation is available on [Github](https://python.kodexa.com)

For more information on how to use Kodexa see https://developer.kodexa.com/developers/clients/python

## Set-up

Ensure you have Anaconda 3 or greater installed, then run:

    conda env create -f environment.yml 
    
Activate the conda environment with the command:

    conda activate kodexa
    pip install -r requirements.txt

## License

Apache 2.0
